/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var ExtraValueTypes = function()
{
	var extraValueTypes = {};
	
	/**
		Initialize the page.
	*/
	extraValueTypes.initPage = function()
	{
		var pageId = Doc.getPageId();		
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', extraValueTypes.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabValidator('settings.info', extraValueTypes.validateExtraValueType);
			
			// Min/Mid/Max values
			Events.addEventHandler('min_value', 'keypress', Events.numberOnly);
			Events.addEventHandler('mid_value', 'keypress', Events.numberOnly);
			Events.addEventHandler('max_value', 'keypress', Events.numberOnly);
			
			// Use colors
			Events.addEventHandler('use_colors', 'click', extraValueTypes.useColorsOnClick);
			Events.addEventHandler('value_type', 'change', extraValueTypes.valueTypeOnChange);
			
			extraValueTypes.useColorsOnClick();
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'EXTRAVALUETYPE', 'item-id': itemId};
			
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'EXTRAVALUETYPE'};
			var tableAttributes = {'table-id': 'extraValueTypes'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);
			
			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}
	
	extraValueTypes.validateExtraValueType = function()
	{
		var frm = document.forms['extraValueType'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		if (Strings.trim(frm.external_id.value) == '')
		{
			Forms.showNotification(frm.external_id, 'You must enter an external ID');
			return false;
		}
		if (frm.use_colors.checked && !frm.use_colors.disabled)
		{
			var minValue = parseFloat(frm.min_value.value);
			var midValue = parseFloat(frm.mid_value.value);
			var maxValue = parseFloat(frm.max_value.value);
			if (isNaN(minValue))
			{
				Forms.showNotification(frm.min_value, 'No min value has been specified');
				return false;
			}
			if (isNaN(midValue))
			{
				Forms.showNotification(frm.mid_value, 'No mid value has been specified');
				return false;
			}
			if (isNaN(maxValue))
			{
				Forms.showNotification(frm.max_value, 'No max value has been specified');
				return false;
			}
			if (minValue > midValue)
			{
				Forms.showNotification(frm.mid_value, 'The mid value can\'t be less than the min value');
				return false;
			}
			if (midValue > maxValue)
			{
				Forms.showNotification(frm.max_value, 'The max value can\'t be less than the mid value');
				return false;
			}
		}
		return true;
	}

	
	extraValueTypes.save = function()
	{
		var frm = document.forms['extraValueType'];
		if (TabControl.validateActiveTab('settings'))
		{
			frm.submit();
		}
	}

	extraValueTypes.useColorsOnClick = function()
	{
		var frm = document.forms['extraValueType'];
		var useColors = frm.use_colors.checked && !frm.use_colors.disabled;
		frm.min_value.disabled = !useColors;
		frm.mid_value.disabled = !useColors;
		frm.max_value.disabled = !useColors;
		frm.logarithmic.disabled = !useColors;
		if (useColors)
		{
			Doc.addClass(frm.min_value, 'required');
			Doc.addClass(frm.mid_value, 'required');
			Doc.addClass(frm.max_value, 'required');
		}
		else
		{
			Doc.removeClass(frm.min_value, 'required');
			Doc.removeClass(frm.mid_value, 'required');
			Doc.removeClass(frm.max_value, 'required');
		}
	}
	
	extraValueTypes.valueTypeOnChange = function()
	{
		var frm = document.forms['extraValueType'];
		var valueType = frm.value_type[frm.value_type.selectedIndex].value;
		var use = valueType != 'STRING';
		frm.use_colors.disabled = !use;
		extraValueTypes.useColorsOnClick();
	}


	return extraValueTypes;
}();

Doc.onLoad(ExtraValueTypes.initPage);
