<%-- $Id: edit_biosource.jsp 7604 2019-02-25 12:19:50Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------


	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.BioSource"
	import="net.sf.basedb.core.ItemSubtype"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.Include"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.BaseException"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.edit.EditUtil"
	import="net.sf.basedb.clients.web.extensions.tabcontrol.TabAction"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.List"
	import="java.util.Set"
	import="java.util.HashSet"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%
final Item itemType = Item.BIOSOURCE;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl();
try
{
	String title = null;
	BioSource bioSource = null;
	boolean readCurrentSubtype = true;
	int currentSubtypeId = 0;

	if (itemId == 0)
	{
		title = "Create biosource";
		cc.removeObject("item");
		
		currentSubtypeId = Values.getInt(request.getParameter("subtype_id"));
		if (currentSubtypeId == 0) 
		{
			int recentSubtypeId = Values.getInt(cc.getRecent(Item.ITEMSUBTYPE.name(), 0));
			currentSubtypeId = Values.getInt(cc.getPropertyValue("itemSubtype"), recentSubtypeId);
		}
	}
	else
	{
		bioSource = BioSource.getById(dc, itemId);
		bioSource.checkPermission(Permission.WRITE);
		
		cc.setObject("item", bioSource);
		title = "Edit biosource -- " + HTML.encodeTags(bioSource.getName());

		try
		{
			ItemSubtype subtype = bioSource.getItemSubtype();
			if (subtype != null) currentSubtypeId = subtype.getId();
		}
		catch (PermissionDeniedException ex)
		{
			readCurrentSubtype = false;
		}

	}
	
	// Query to retrieve item types
	final ItemQuery<ItemSubtype> subtypesQuery = Base.getSubtypesQuery(itemType);
	subtypesQuery.include(Include.ALL);
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, GuiContext.item(itemType), bioSource);
	ExtensionsInvoker<TabAction> invoker = EditUtil.useEditExtensions(jspContext);
	%>
	<base:page type="popup" title="<%=title%>" id="edit-page">
	<base:head scripts="tabcontrol-2.js,subtypes.js,~biosources.js" styles="tabcontrol.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<h1><%=title%> <base:help tabcontrol="settings" /></h1>
			
		<form action="index.jsp?ID=<%=ID%>" method="post" name="biosource">
		<input type="hidden" name="cmd" value="UpdateItem">

		<t:tabcontrol id="settings"
			subclass="content dialogtabcontrol"
			position="bottom"  remember="<%=bioSource != null%>"
			extensions="<%=invoker%>">
		<t:tab id="info" title="Biosource" helpid="biosource.edit">
			<table class="fullform input100">
			<tr>
				<th>Name</th>
				<td><input class="text required auto-init" data-auto-init="<%=bioSource == null ? "focus-select" : "focus" %>"
					type="text" name="name" 
					value="<%=HTML.encodeTags(bioSource == null ? Values.getString(cc.getPropertyValue("name"), "New biosource") : bioSource.getName())%>" 
					maxlength="<%=BioSource.MAX_NAME_LENGTH%>"></td>
				<td></td>
			</tr>
			<tr>
				<th>Type</th>
				<td>
					<select name="subtype_id"
						<%=!readCurrentSubtype ? "disabled readonly class=\"disabled selectionlist\"" : "class=\"selectionlist\""%>>
					<%
					if (!readCurrentSubtype)
					{
						%>
						<option value="-1">- denied -
						<%
					}
					else
					{
						%>
						<option value="0">-none-
						<%
						for (ItemSubtype subtype : subtypesQuery.list(dc))
						{
							int id = subtype.getId();
							if (id != currentSubtypeId && subtype.isRemoved()) continue;
							%>
							<option value="<%=id == currentSubtypeId && bioSource != null ? -id : id%>" 
								<%=id == currentSubtypeId ? "selected" : ""%>
								title="<%=HTML.encodeTags(subtype.getDescription()) %>"
								><%=HTML.encodeTags(subtype.getName())%>
							<%
						}
					}
					%>
					</select>
				</td>
				<td></td>
			</tr>
			<tr>
				<th>External ID</th>
				<td><input class="text" type="text" name="external_id" 
					value="<%=HTML.encodeTags(bioSource == null ? Values.getString(cc.getPropertyValue("externalId"), "") : bioSource.getExternalId())%>" 
					maxlength="<%=BioSource.MAX_EXTERNAL_ID_LENGTH%>"></td>
				<td></td>
			</tr>
			<tr class="dynamic">
				<th>Description</th>
				<td>
					<textarea class="text" rows="6"  name="description" id="description"
						><%=HTML.encodeTags(bioSource == null ? cc.getPropertyValue("description") : bioSource.getDescription())%></textarea>
				</td>
				<td style="width: 20px;">
					<base:zoom textarea="description" title="Description" />
				</td>
			</tr>
			</table>
		</t:tab>

		<t:tab id="annotations" title="Annotations" helpid="annotations.edit">
			<jsp:include page="../../common/annotations/annotate_frameset.jsp">
				<jsp:param name="item_type" value="<%=itemType.name()%>" />
				<jsp:param name="item_id" value="<%=itemId%>" />
				<jsp:param name="ID" value="<%=ID%>" />
			</jsp:include>
		</t:tab>
		</t:tabcontrol>
		</form>

		<div class="legend">
			<base:icon image="required.png" />= required information
		</div>

		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Save" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
