<%-- $Id: save_preset.jsp 6607 2014-11-19 14:52:20Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2020 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.AnyToAny"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Metadata"
	import="net.sf.basedb.util.AnyToAnyLinkStatistics"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="java.util.Arrays"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final Item itemType = Item.valueOf(request.getParameter("item_type"));
final String subContext = Values.getString(request.getParameter("subcontext"), "");
final ItemContext cc = Base.getAndSetCurrentContext(sc, Item.ANYTOANY, null, null);
final DbControl dc = sc.newDbControl();
try
{
	ItemQuery<?> statQuery = itemType.getQuery();
	ItemContext ccList = Base.getAndSetCurrentContext(sc, itemType, subContext, null, null);
	ccList.configureQuery(dc, statQuery, true);
	statQuery.setMaxResults(-1);
	statQuery.setFirstResult(0);
	final List<AnyToAnyLinkStatistics> stats = AnyToAny.getExistingLinkStatistics(dc, statQuery, new AnyToAnyLinkStatistics.Options());
	%>
	<base:page type="popup" title="Add linked item column">
	<base:head scripts="~add_linkeditem_column.js" />
	<base:body>
		<h1>Add linked item column <base:help helpid="columns.configure.add_linkeditem_column" /></h1>
	
		<form name="linkedItems" method="post">
		<input type="hidden" name="ID" value="<%=ID%>">
		<input type="hidden" name="item_type" value="<%=itemType.name()%>">
		
		<div class="content">
			<table class="fullform input100 bottomborder">
			<%
			if (stats.size() > 0)
			{
				%>
				<tr>
					<th></th>
					<td>
						<select name="presets" id="presets" style="width: 25em;">
						<option value="">- presets -
						<%
						for (AnyToAnyLinkStatistics stat : stats)
						{
							String name = HTML.encodeTags(stat.getLinkName());
							String targetType = stat.getTargetType().name();
							%>
							<option data-linkname="<%=name%>" data-targettype="<%=targetType%>"><%=name%> [<%=targetType%>]
							<%
						}
						%>
						</select>
					</td>
				</tr>
				<%
			}
			%>
			<tr>
				<th style="border-top-width: 0;">Link name</th>
				<td>
					<input class="text required auto-init" data-auto-init="focus" 
						type="text" name="linkName" id="linkName" style="width: 25em;">
				</td>
			</tr>
			<tr>
				<th>Target item type</th>
				<td>
					<select name="targetItemType" id="targetItemType" style="min-width: 25em;">
					<option value="">- any -
					<%
					List<String> recentTypes = cc.getRecent("toTypes");
					if (recentTypes.size() == 0)
					{
						recentTypes = Arrays.asList("FILE");
					}
					%>
					<option value="0" disabled class="recentheader">- recently used -
					<%
					for (String r : recentTypes)
					{
						%>
						<option value="<%=r%>"><%=r%>
						<%
					}
					%>
					<option value="0" disabled class="recentheader">- all -
					<%
					for (Item targetItem : Metadata.getNameableItems())
					{
						if (targetItem.getDefinedPermissions() != null)
						{
							%>
							<option value="<%=targetItem.name() %>"><%=targetItem.name() %>
							<%
						}
					}
					%>
					</select>
				</td>
			</tr>
			<tr class="dynamic">
				<th></th>
				<td><div id="added-column-msg" class="messagecontainer note" style="display:none; margin: 0.5em 0;"></div></td>
			</tr>
			</table>
		</div>
		</form>
	
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnAdd" title="Add" />
			<base:button id="close" title="Close" />
		</base:buttongroup>
	
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>


