/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2020 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var Configure = function()
{
	var configure = {};
	
	var currentSubtypes;
	var currentAnnotationTypesAll;
	var currentAnnotationTypesCategory;
	
	// See also net.sf.basedb.clients.web.extensions.list.RelatedItemColumn.pathTitles

	var nameCol = {'id': '.', 'text': 'Name'};
	var externalIdCol = {'id': 'externalId', 'text': 'External ID'};
	var bioPlateCol = {'id': 'bioWell.bioPlate', 'text': 'Bioplate'};
	var entryDateCol = {'id': 'entryDate', 'text': 'Registered'};
	var remainingQCol = {'id': 'remainingQuantity', 'text': 'Remaining quantity'};
	var originalQCol = {'id': 'originalQuantity', 'text': 'Original quantity'};
	
	var creationRegistredCol = {'id': 'creationEvent.entryDate', 'text': 'Registration date'};
	var creationEventdateCol = {'id': 'creationEvent.eventDate', 'text': 'Creation date'};
	var creationProtocolCol = {'id': 'creationEvent.protocol', 'text': 'Protocol'};
	var creationHardwareCol = {'id': 'creationEvent.hardware', 'text': 'Hardware'};

	var protocolCol = {'id': 'protocol', 'text': 'Protocol'};
	var hardwareCol = {'id': 'hardware', 'text': 'Hardware'};
	var softwareCol = {'id': 'software', 'text': 'Software'};
	var tagCol = {'id': 'tag', 'text': 'Tag'};
	var jobTypeCol = {'id': 'job.itemSubtype', 'text': 'Job type'};

	var staticColumns = {
		'BIOSOURCE': [nameCol, externalIdCol, entryDateCol],
		'SAMPLE': [nameCol, externalIdCol, bioPlateCol, creationEventdateCol, creationRegistredCol, creationProtocolCol, remainingQCol, originalQCol],
		'EXTRACT': [nameCol, externalIdCol, bioPlateCol, creationEventdateCol, creationRegistredCol, creationProtocolCol, remainingQCol, originalQCol, tagCol],
		'PHYSICALBIOASSAY': [nameCol, creationEventdateCol, creationRegistredCol, creationProtocolCol, creationHardwareCol],
		'DERIVEDBIOASSAY': [nameCol, entryDateCol, protocolCol, softwareCol, hardwareCol, jobTypeCol],
		'RAWBIOASSAY': [nameCol, entryDateCol, protocolCol, softwareCol, jobTypeCol]
	}
	
	/**
		Initialize the page.
	*/
	configure.initPage = function()
	{
		Events.addEventHandler('targetItemType', 'change', configure.targetItemTypeOnChange);
		Events.addEventHandler('subtype', 'change', configure.subtypeOnChange);
		Events.addEventHandler('showAllAnnotationTypes', 'change', configure.updateColumnsList);
		Events.addEventHandler('column', 'dblclick', configure.addColumn);
		Events.addEventHandler(document.body, 'click', configure.hideMessage);
		
		// Buttons
		Buttons.addClickHandler('close', App.closeWindow);
		Buttons.addClickHandler('btnAdd', configure.addColumn);
	}
	

	configure.subtypeOnChange = function(event)
	{
		var frm = document.forms['relatedItems'];
		var targetItemType = frm.targetItemType.value;
		var category = frm.subtype[frm.subtype.selectedIndex].text;
		if (targetItemType && category)
		{
			var url = 'ajax.jsp?ID='+App.getSessionId();
			url += '&cmd=GetAnnotationTypesForCategory&itemType='+encodeURIComponent(targetItemType);
			url += '&category='+encodeURIComponent(category);
			
			var request = Ajax.getXmlHttpRequest();
			request.open("GET", url, true);
			request.send(null);
			Ajax.setReadyStateHandler(request, configure.typeInfoLoaded, configure.typeInfoLoaded);
		}
	}
	
	configure.targetItemTypeOnChange = function(event)
	{
		var targetItemType = event.currentTarget.value;
		if (targetItemType)
		{
			var url = 'ajax.jsp?ID='+App.getSessionId();
			url += '&cmd=GetSubtypesAndAnnotationTypes&itemType='+encodeURIComponent(targetItemType);
			
			var request = Ajax.getXmlHttpRequest();
			request.open("GET", url, true);
			request.send(null);
			Ajax.setReadyStateHandler(request, configure.typeInfoLoaded, configure.typeInfoLoaded);
		}
	}
	
	configure.typeInfoLoaded = function(request)
	{
		var response = JSON.parse(request.responseText);
		if (response.status != 'ok')
		{
			App.debug(request.responseText);
			return;
		}
		
		var frm = document.forms['relatedItems'];
		if (response.subtypes) 
		{
			currentSubtypes = response.subtypes;
			frm.subtype.length = 1;
			for (var i = 0; i < currentSubtypes.length; i++)
			{
				var st = currentSubtypes[i];
				frm.subtype[frm.subtype.length] = new Option(st.name, st.id);
			}
			frm.subtype.selectedIndex = 0;
		}
		if (response.annotationTypes) currentAnnotationTypesAll = response.annotationTypes;
		if (response.annotationTypesCategory) currentAnnotationTypesCategory = response.annotationTypesCategory;
		configure.updateColumnsList();
	}
	
	configure.updateColumnsList = function()
	{
		var frm = document.forms['relatedItems'];
		
		var targetItemType = frm.targetItemType.value;
		var subtype = frm.subtype.value;

		if (!targetItemType || !subtype)
		{
			frm.column.length = 0;
			return;
		}
		
		var annotationTypes = frm.showAllAnnotationTypes.checked ? currentAnnotationTypesAll : currentAnnotationTypesCategory;
		frm.column.length = 0;
		
		// Add static property columns depending on itemtype
		var cols = staticColumns[targetItemType] || [];
		for (var i = 0; i < cols.length; i++)
		{
			var c = cols[i];
			frm.column[frm.column.length] = new Option(c.text, c.id);
		}
		
		// Add annotation columns
		for (var i = 0; i < annotationTypes.length; i++)
		{
			var at = annotationTypes[i];
			frm.column[frm.column.length] = new Option(at.name+" [A]", "#"+at.id);
		}
		frm.column.selectedIndex = -1;			
	}
	
	
	configure.addColumn = function(event)
	{
		var frm = document.forms['relatedItems'];
		
		var data = {};
		data.targetItemType = frm.targetItemType.value;
		data.subtype = frm.subtype.value;

		if (!data.targetItemType)
		{
			Forms.showNotification('targetItemType', 'Please select a parent or child item type!');
			return;
		}
		
		if (!data.subtype)
		{
			Forms.showNotification('subtype', 'Please select a subtype!');
			return;
		}
		data.subtypeName = frm.subtype[frm.subtype.selectedIndex].text;
		data.direction = Data.get(frm.targetItemType[frm.targetItemType.selectedIndex], 'direction');

		var numSelected = 0;
		for (var i = 0; i < frm.column.length; i++)
		{
			if (frm.column[i].selected)
			{
				var col = frm.column[i];
				data.column = col.value;
				data.property = '/'+data.direction+'/'+data.targetItemType+'/'+data.subtype+'/'+data.column;
				data.title = data.subtypeName + (col.value == '.' ? '' : '.'+col.text);
				Events.sendCustomEvent(window.opener.Doc.element('selectRelatedItemColumn'), 'base-selected', data);
				numSelected++;
			}
		}
		
		if (numSelected == 0)
		{
			Forms.showNotification('column', 'Please select a column!');
			return;
		}
		
		for (var i = frm.column.length-1; i >= 0; i--)
		{
			if (frm.column[i].selected) frm.column[i] = null;
		}
		Doc.element('added-column-msg').innerHTML = numSelected == 1 ? 
			'1 column has been added to the table.' : numSelected + ' columns have been added to the table.';
		Doc.show('added-column-msg');
		event.stopPropagation(); // To prevent the hideMessage() method from executing
	}
	
	configure.hideMessage = function(event)
	{
		Doc.hide('added-column-msg');
	}
	
	return configure;
}();

Doc.onLoad(Configure.initPage);