<%-- $Id: edit_file_data.jsp 7626 2019-03-07 13:43:04Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.Directory"
	import="net.sf.basedb.core.File"
	import="net.sf.basedb.core.Location"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.BaseException"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.core.Config"
	import="java.util.List"
	import="java.util.Set"
	import="java.util.HashSet"
	import="java.nio.charset.Charset"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%
final Item itemType = Item.FILE;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl();
try
{
	final File file = File.getById(dc, itemId);
	final String mimeType = file.getMimeType();
	final boolean editable = file.hasPermission(Permission.WRITE) && !file.isWriteProtected() &&
		mimeType != null &&  mimeType.startsWith("text/") && 
		file.getSize() < 102400 && file.getLocation() == Location.PRIMARY;

	if (!editable)
	{
		throw new PermissionDeniedException("Online editing of file is not allowed: " + file);
	}
	final String path = file.getPath().toString();
	final String title = "Edit file -- " + HTML.encodeTags(file.getName());
	%>
	<base:page type="popup" title="<%=title%>">
	<base:head styles="toolbar.css" scripts="~edit_file_data.js">
		<style>
		#linenumbers
		{
			position: absolute;
			top: 0;
			left: 0;
			bottom: 0;
			width: 3.6em;
			padding-top: 2px;
			padding-right: 0.4em;
			text-align: right;
			overflow: hidden;
			color: #224488;
			background: #E8E8E8;
			font-family: monospace,Courier New;
			border-right: 2px solid #224488;
		}
		
		#filecontainer
		{
			position: absolute;
			top: 2px;
			left: 4em;
			bottom: 0;
			right: 0;
			margin-left: 2px;
		}
		
		#filedata
		{
			width: 100%; 
			height: 100%; 
			border: 0;
			margin: 0;
			padding: 0;
		}
		
		.bigger-notify
		{
			width: 30em;
		}
		
		#charsetSection
		{
			top: auto; 
			bottom: 0; 
			height: 2.4em; 
			left: auto; 
			right: calc(50% + 7em);
			z-index: 2;
		}
		
		#nonUtf8Warning
		{
			visibility: hidden;
		}
		
		#charsetSection.utf8-warning #nonUtf8Warning
		{
			visibility: visible;
		}
		</style>
	</base:head>
	<base:body>
		<h1><%=title%> <span id="modified"></span> <base:help helpid="file.edit.data" /></h1>
		
		<div id="page-data" class="datacontainer"
			data-path="<%=HTML.encodeTags(path) %>"
			data-file-id="<%=itemId %>"
		></div>
		
		<form action="index.jsp?ID=<%=ID%>" method="post" name="file">
		<input type="hidden" name="cmd" value="UpdateItem">
		
		<div class="content bottomborder" style="overflow: hidden;">
			<div id="linenumbers"></div>
			<div id="filecontainer">
			<textarea id="filedata" name="filedata" 
				wrap="off" style="overflow: auto;"
				>Loading file; please wait...</textarea>
			</div>
		</div>

		<div id="charsetSection" class="absolutefull">
			<b>Character set</b>
			<select name="charset" id="charset">
			<%
			String currentCharset = Values.getString(file.getCharacterSet(), "UTF-8");
			int numCommon = Config.getCommonCharsets().size();
			int i = 0;
			boolean hasSelected = false;
			for (String charset : Config.getAllCharsets())
			{
				// The UTF-32 charset is not working well in browsers and we do not include non-encoding character sets
				if (charset.startsWith("UTF-32") || !Charset.forName(charset).canEncode()) continue;
				boolean selected = false;
				if (!hasSelected)
				{
					selected = charset.equalsIgnoreCase(currentCharset);
					hasSelected |= selected;
				}
				%>
				<option value="<%=charset%>" <%=selected ? "selected" : ""%> 
					<%=i==numCommon ? "style=\"border-top: 1px solid #666666;\"" : "" %>><%=charset%>
				<%
				i++;
			}
			if (!hasSelected && currentCharset != null)
			{
				%>
				<option value="<%=currentCharset%>" selected><%=currentCharset%>
				<%
			}
			%>
			</select>
			<span id="nonUtf8Warning"><img src="../../images/warning.png" 
				title="The selected character set may not be able to encode all characters"></span>
		</div>
		</form>
		
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Save" />
			<base:button id="close" title="Close" />
		</base:buttongroup>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
