/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/
'use strict';

var Settings = function()
{
	var extendedProperties = null;
	
	var settings = {};
	
	settings.initPage = function()
	{
		// Save + Close buttons
		Buttons.addClickHandler('btnSave', Settings.save);
		Buttons.addClickHandler('close', App.closeWindow);
		
		// Tab validation
		TabControl.addTabValidator('settings.contact', Settings.validateContact);
		TabControl.addTabValidator('settings.password', Settings.validatePassword);
		TabControl.addTabValidator('settings.other', Settings.validateExtendedProperties);
		
		// Extended properties
		var pageData = Doc.element('page-data');
		extendedProperties = Data.json(pageData, 'extended-properties');
		for (var i = 0; i < extendedProperties.length; i++)
		{
			var ep = extendedProperties[i];
			var valueType = ep.valueType;
			var fieldName = 'ep.'+ep.name;
			
			if (valueType == 'INT' || valueType == 'LONG')
			{
				// Block non-numeric keys from INT and LONG fields
				Events.addEventHandler(fieldName, 'keypress', Events.integerOnly);
			}
			else if (valueType == 'FLOAT' || valueType == 'DOUBLE')
			{
				// Block non-numeric keys from FLOAT and DOUBLE fields
				Events.addEventHandler(fieldName, 'keypress', Events.numberOnly);
			}
			else if (valueType == 'DATE' || valueType == 'TIMESTAMP')
			{
				// Add click handler to open calendar dialog for date/timestamp fields
				Buttons.addClickHandler('btn.'+fieldName, settings.openCalendar);
			}
		}
	}
	
	// Open the calendar dialog
	settings.openCalendar = function(event)
	{
		var epName = Data.get(event.currentTarget, 'extended-property');
		var ep = null;
		for (var i = 0; i < extendedProperties.length; i++)
		{
			if (extendedProperties[i].name == epName)
			{
				ep = extendedProperties[i];
				i = extendedProperties.length;
			}
		}
		if (ep==null) return;
		
		var textarea = 'ep.'+ep.name;
		var title = ep.title;
		var useTime = ep.valueType != 'TIMESTAMP';
		var format = Data.get('page-data', useTime ? 'datetime-format' : 'date-format');
		Dialogs.openCalendar(textarea, title, format, useTime);
	}
	
	// Validate the 'Contact information' tab
	settings.validateContact = function()
	{
		return true;
	}
	
	// Validate the 'Password' tab
	settings.validatePassword = function()
	{
		var frm = document.forms['user'];
		if (frm.password.value != frm.retype_password.value)
		{
			Forms.showNotification(frm.retype_password, 'The two passwords do not match');
			return false;
		}
		return true;
	}

	// Validate the 'Other information' tab with extended properties
	settings.validateExtendedProperties = function()
	{
		var frm = document.forms['user'];
		var pageData = Doc.element('page-data');
		var dateFormat = Data.get(pageData, 'date-format');
		var dateTimeFormat = Data.get(pageData, 'datetime-format');
		
		for (var i = 0; i < extendedProperties.length; i++)
		{
			var ep = extendedProperties[i];
			var valueType = ep.valueType;
			var field = frm['ep.'+ep.name];
			
			if (ep.valueType == 'DATE')
			{
				if (field.value != '' && !Dates.isDate(field.value, dateFormat))
				{
					Forms.showNotification(field, "'"+field.value+"' is not a valid date for '" + ep.title + "'");
					return false;
				}
			}
			else if (ep.valueType == 'TIMESTAMP')
			{
				if (field.value != '' && !Dates.isDate(field.value, dateTimeFormat))
				{
					Forms.showNotification(field, "'"+field.value+"' is not a valid timestamp for '" + ep.title + "'");
					return false;
				}
			}
			if (!ep.nullable)
			{
				if (ep.valueType == 'BOOLEAN')
				{
					if (Forms.getCheckedRadio(field) == null)
					{
						Forms.showNotification(field[0], "You must select a value for '" + ep.title + "'");
						return false;
					}
				}
				else
				{
					if (Strings.trim(field.value) == '')
					{
						Forms.showNotification(field, "You must enter a value for '" + ep.title + "'");
						return false;
					}
				}
			}
		}	
		return true;
	}
	
	settings.save = function()
	{
		var frm = document.forms['user'];
		if (TabControl.validateActiveTab('settings'))
		{
			frm.submit();
		}
	}
	
	return settings;
}();

Doc.onLoad(Settings.initPage);